@@ -168,11 +168,11 @@ def atom_refine(image, atoms, radius, max_int=0, min_int=0, max_dist=4):
 
         append = False
 
-        if (x - rr) < 0 or y - rr < 0 or x + rr + 1 > image.shape[0] or y + rr + 1 > image.shape[1]:
+        if (x - rr) < 0 or y - rr < 0 or x + rr + 1 > image.shape[0] or y + rr + 1 > image.shape[1]:  # atom not found
             position.append(-1)
             intensities.append(-1.)
             maximum_area.append(-1.)
-        else:
+        else:  # atom found
             position.append(1)
             intensities.append((area * mask).sum())
             maximum_area.append((area * mask).max())
